<?php

function printLog($message = '')
{
    if (false) {
        error_log($message);
    }
}

function generatePlaylistName()
{
    $now = new DateTime();
    $name = 'Fresh playlist ['.$now->format('Y-m-d H:i:s').']';

    return $name;
}

function createEmptyPlaylist($api)
{
    $name = generatePlaylistName();
    printLog('Create new playlist "'.$name.'".');
    $playlist = $api->createPlaylist([
        'name' => $name,
    ]);

    return $playlist;
}

function pickRandomTracksFromArray($recommendedTrackIds, $count = 50)
{
    $recommendedTrackIds = array_keys($recommendedTrackIds);
    printLog('=> Got '.count($recommendedTrackIds).' unique recommendatations.');
    shuffle($recommendedTrackIds);
    $pickedTrackIds = array_slice($recommendedTrackIds, 0, $count);
    printLog('Keep '.count($pickedTrackIds).' random tracks.');

    return $pickedTrackIds;
}

function getRandomArtistsFromTopArtists($api, $countInTopArtists, $countInLessTopArtists, $limitBetweenTopAndLessTop)
{
    $top = $api->getMyTop(
        'artists',
        [
          'limit' => $limitBetweenTopAndLessTop,
          'time_range' => 'short_term'
        ]
        )->items;
    shuffle($top);
    $pickedTop = array_slice($top, 0, $countInTopArtists);

    $lessTop = $api->getMyTop(
        'artists',
        [
          'limit' => $limitBetweenTopAndLessTop,
          'offset' => $limitBetweenTopAndLessTop,
          'time_range' => 'short_term'
        ]
        )->items;
    shuffle($lessTop);
    $pickedLessTop = array_slice($lessTop, 0, $countInLessTopArtists);

    $randomlySelected = [];
    foreach ($pickedTop as $artist) {
        $randomlySelected[] = $artist->id;
    }
    foreach ($pickedLessTop as $artist) {
        $randomlySelected[] = $artist->id;
    }

    return $randomlySelected;
}

function createPlaylistWithRandomTracks($api, $trackIds, $count = 50)
{
    $playlist = createEmptyPlaylist($api);
    $pickedTrackIds = pickRandomTracksFromArray($trackIds, $count);
    $api->replacePlaylistTracks($playlist->id, $pickedTrackIds);

    return $api->getPlaylist($playlist->id);
}

function getCreatedPlaylistInformationMessage($api, $playlist)
{
    $link = '<a href="'.$playlist->external_urls->spotify.'">'.$playlist->name.'</a>';
    $message = 'Ok created new playlist with '.count($playlist->tracks->items).' tracks: '.$link;

    return $message;
}

function createDisplayablePlaylist($playlist)
{
    $output = [
        'id' => $playlist->id,
        'name' => $playlist->name,
        'tracks' => [],
        'artists' => [],
    ];

    $artists = [];

    foreach ($playlist->tracks->items as $item) {
        $track = [
            'id' => $item->track->id,
            'name' => $item->track->name,
            'artists' => [],
        ];

        foreach ($item->track->artists as $artist) {
            $track['artists'][] = [
                'id' => $artist->id,
                'name' => $artist->name,
            ];
            $artists[$artist->id] = $artist->name;
        }

        $output['tracks'][] = $track;
    }

    $output['artists'] = array_values($artists);

    return $output;
}
